pub struct Config;Trait Implementations
Sourceimpl Actor for Config
impl Actor for Config
Sourcetype Msg = ConfigMessage
type Msg = ConfigMessage
The message type for this actor
Sourcetype State = ConfigState
type State = ConfigState
The type of state this actor manages internally
Sourcetype Arguments = ConfigArgs
type Arguments = ConfigArgs
Initialization arguments
Sourcefn pre_start<'life0, 'async_trait>(
&'life0 self,
_myself: ActorRef<Self::Msg>,
args: Self::Arguments,
) -> Pin<Box<dyn Future<Output = Result<Self::State, ActorProcessingErr>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn pre_start<'life0, 'async_trait>(
&'life0 self,
_myself: ActorRef<Self::Msg>,
args: Self::Arguments,
) -> Pin<Box<dyn Future<Output = Result<Self::State, ActorProcessingErr>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Invoked when an actor is being started by the system. Read more
Sourcefn post_start<'life0, 'life1, 'async_trait>(
&'life0 self,
myself: ActorRef<Self::Msg>,
state: &'life1 mut Self::State,
) -> Pin<Box<dyn Future<Output = Result<(), ActorProcessingErr>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn post_start<'life0, 'life1, 'async_trait>(
&'life0 self,
myself: ActorRef<Self::Msg>,
state: &'life1 mut Self::State,
) -> Pin<Box<dyn Future<Output = Result<(), ActorProcessingErr>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Invoked after an actor has started. Read more
Sourcefn handle<'life0, 'life1, 'async_trait>(
&'life0 self,
myself: ActorRef<Self::Msg>,
message: Self::Msg,
state: &'life1 mut Self::State,
) -> Pin<Box<dyn Future<Output = Result<(), ActorProcessingErr>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn handle<'life0, 'life1, 'async_trait>(
&'life0 self,
myself: ActorRef<Self::Msg>,
message: Self::Msg,
state: &'life1 mut Self::State,
) -> Pin<Box<dyn Future<Output = Result<(), ActorProcessingErr>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Handle the incoming message from the event processing loop. Unhandled panickes will be
captured and sent to the supervisor(s) Read more
Sourcefn post_stop<'life0, 'life1, 'async_trait>(
&'life0 self,
_myself: ActorRef<Self::Msg>,
state: &'life1 mut Self::State,
) -> Pin<Box<dyn Future<Output = Result<(), ActorProcessingErr>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn post_stop<'life0, 'life1, 'async_trait>(
&'life0 self,
_myself: ActorRef<Self::Msg>,
state: &'life1 mut Self::State,
) -> Pin<Box<dyn Future<Output = Result<(), ActorProcessingErr>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Invoked after an actor has been stopped to perform final cleanup. In the
event the actor is terminated with Signal::Kill or has self-panicked,
post_stop won’t be called. Read moreSourcefn handle_supervisor_evt<'life0, 'life1, 'async_trait>(
&'life0 self,
myself: ActorRef<Self::Msg>,
message: SupervisionEvent,
state: &'life1 mut Self::State,
) -> Pin<Box<dyn Future<Output = Result<(), Box<dyn Error + Sync + Send>>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn handle_supervisor_evt<'life0, 'life1, 'async_trait>(
&'life0 self,
myself: ActorRef<Self::Msg>,
message: SupervisionEvent,
state: &'life1 mut Self::State,
) -> Pin<Box<dyn Future<Output = Result<(), Box<dyn Error + Sync + Send>>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Handle the incoming supervision event. Unhandled panics will be captured and
sent the the supervisor(s). The default supervision behavior is to exit the
supervisor on any child exit. To override this behavior, implement this function. Read more
Sourcefn spawn<'async_trait>(
name: Option<String>,
handler: Self,
startup_args: Self::Arguments,
) -> Pin<Box<dyn Future<Output = Result<(ActorRef<Self::Msg>, JoinHandle<()>), SpawnErr>> + Send + 'async_trait>>where
Self: 'async_trait,
fn spawn<'async_trait>(
name: Option<String>,
handler: Self,
startup_args: Self::Arguments,
) -> Pin<Box<dyn Future<Output = Result<(ActorRef<Self::Msg>, JoinHandle<()>), SpawnErr>> + Send + 'async_trait>>where
Self: 'async_trait,
Spawn an actor of this type, which is unsupervised, automatically starting Read more
Sourcefn spawn_linked<'async_trait>(
name: Option<String>,
handler: Self,
startup_args: Self::Arguments,
supervisor: ActorCell,
) -> Pin<Box<dyn Future<Output = Result<(ActorRef<Self::Msg>, JoinHandle<()>), SpawnErr>> + Send + 'async_trait>>where
Self: 'async_trait,
fn spawn_linked<'async_trait>(
name: Option<String>,
handler: Self,
startup_args: Self::Arguments,
supervisor: ActorCell,
) -> Pin<Box<dyn Future<Output = Result<(ActorRef<Self::Msg>, JoinHandle<()>), SpawnErr>> + Send + 'async_trait>>where
Self: 'async_trait,
Spawn an actor of this type with a supervisor, automatically starting the actor Read more