pub struct MetricsSnapshot {
pub agent_id: String,
pub start: i64,
pub end: i64,
pub data: SnapshotData,
}Expand description
A 5-minute metrics snapshot containing all metrics for a window
This is the new format that groups all metrics into a single document with time-series arrays per metric, rather than individual points.
Fields
agent_id: Stringstart: i64end: i64data: SnapshotDataTrait Implementations
Sourceimpl Clone for MetricsSnapshot
impl Clone for MetricsSnapshot
Sourcefn clone(&self) -> MetricsSnapshot
fn clone(&self) -> MetricsSnapshot
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetricsSnapshot
impl Debug for MetricsSnapshot