Agent

Struct Agent 

pub struct Agent { /* private fields */ }
The main agent handle returned by the builder

Holds references to the root supervisor and can be used to run the agent until shutdown.

Implementations

Source

impl Agent

pub fn builder() -> AgentBuilder

Create a new agent builder

This is the recommended way to create an agent. Use .build().await to construct the agent after configuration.

Example
use elo::Agent;

let agent = Agent::builder()
    .storage_path("/var/lib/loa")
    .dashboard_port(3000)
    .build()
    .await?;
pub async fn run(self) -> Result<()>

Run the agent until shutdown signal (Ctrl+C)

This will block until:

  • Ctrl+C is pressed
  • An unrecoverable error occurs
  • shutdown() is called from another task
Example
use elo::Agent;

let agent = Agent::builder()
    .storage_path("/var/lib/loa")
    .build()
    .await?;

agent.run().await?;