pub struct AgentIdentity { /* private fields */ }Implementations
Sourceimpl AgentIdentity
impl AgentIdentity
pub fn from_file_or_generate_new(path: &Path) -> Result<Self>
pub fn peer_id(&self) -> &PeerId
pub fn ed25519_public_key_hex(&self) -> &str
pub fn x25519_public_key_hex(&self) -> &str
pub fn sign_message_as_hex(&self, message: &[u8]) -> Result<String>
Sourcepub fn decrypt_x25519(
&self,
encrypted_data: &[u8],
nonce: &[u8],
) -> Result<Vec<u8>, String>
pub fn decrypt_x25519( &self, encrypted_data: &[u8], nonce: &[u8], ) -> Result<Vec<u8>, String>
Decrypt data using x25519 + XChaCha20-Poly1305
Note: This method is reserved for future encrypted communication features (e.g., encrypted config updates, encrypted metrics). Currently unused but maintained for forward compatibility with the encryption package.
Expected format of encrypted_data:
- First 32 bytes: ephemeral x25519 public key
- Remaining bytes: XChaCha20-Poly1305 ciphertext (includes auth tag)