pub struct Agent { /* private fields */ }Expand description
The main agent handle returned by the builder
Holds references to the root supervisor and can be used to run the agent until shutdown.
Implementations
Sourceimpl Agent
impl Agent
Sourcepub fn builder() -> AgentBuilder
pub fn builder() -> AgentBuilder
Create a new agent builder
This is the recommended way to create an agent.
Use .build().await to construct the agent after configuration.
Example
use elo::Agent;
let agent = Agent::builder()
.storage_path("/var/lib/loa")
.dashboard_port(3000)
.build()
.await?;Sourcepub async fn run(self) -> Result<()>
pub async fn run(self) -> Result<()>
Run the agent until shutdown signal (Ctrl+C)
This will block until:
- Ctrl+C is pressed
- An unrecoverable error occurs
- shutdown() is called from another task
Example
use elo::Agent;
let agent = Agent::builder()
.storage_path("/var/lib/loa")
.build()
.await?;
agent.run().await?;Auto Trait Implementations
impl Freeze for Agent
impl RefUnwindSafe for Agent
impl Send for Agent
impl Sync for Agent
impl Unpin for Agent
impl UnwindSafe for Agent